<TS language="sq" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Krijo një adresë të re</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;E re</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopjo adresën e zgjedhur në memorjen e sistemit </translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopjo</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Fshi adresen e selektuar nga lista</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Fshi</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopjo &amp;Etiketë</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Ndrysho</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiketë</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresë</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(pa etiketë)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Futni frazkalimin</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Frazkalim i ri</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Përsërisni frazkalimin e ri</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Kripto portofolin</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Ky veprim ka nevojë per frazkalimin e portofolit tuaj që të ç'kyç portofolin.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>ç'kyç portofolin.</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Ndrysho frazkalimin</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Futni frazkalimin e vjetër dhe të ri në portofol. </translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Konfirmoni enkriptimin e portofolit</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Jeni te sigurt te enkriptoni portofolin tuaj?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Portofoli u enkriptua</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Enkriptimi i portofolit dështoi</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Enkriptimi i portofolit dështoi për shkak të një gabimi të brëndshëm. portofoli juaj nuk u enkriptua.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Frazkalimet e plotësuara nuk përputhen.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>ç'kyçja e portofolit dështoi</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Frazkalimi i futur për dekriptimin e portofolit nuk ishte i saktë.</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Portofol</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Përmbledhje</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Trego një përmbledhje te përgjithshme të portofolit</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Dergo</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Merr</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Shfleto historinë e transaksioneve</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Mbyllni aplikacionin</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsione</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Shfaq / Fsheh</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Ndrysho frazkalimin e përdorur per enkriptimin e portofolit</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Skedar</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Konfigurimet</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ndihmë</translation>
    </message>
    <message>
        <source>[testnet]</source>
        <translation>[testo rrjetin]</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>I azhornuar</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Duke u azhornuar...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Dërgo transaksionin</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transaksion në ardhje</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Portofoli po &lt;b&gt; enkriptohet&lt;/b&gt; dhe është &lt;b&gt; i kyçur&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Shuma:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sasia</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresë</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopjo adresën</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>po</translation>
    </message>
    <message>
        <source>no</source>
        <translation>jo</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(pa etiketë)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Ndrysho Adresën</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiketë</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Adresë e re pritëse</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Adresë e re dërgimi</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Ndrysho adresën pritëse</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>ndrysho adresën dërguese</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Adresa e dhënë "%1" është e zënë në librin e adresave. </translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Nuk mund të ç'kyçet portofoli.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Krijimi i çelësit të ri dështoi.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsionet</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formilarë</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Informacion</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Hap</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Pastro</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Dërgo Monedha</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fonde te pamjaftueshme</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Shuma:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Dërgo marrësve të ndryshëm njëkohësisht</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Konfirmo veprimin e dërgimit</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>konfirmo dërgimin e monedhave</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Shuma e paguar duhet të jetë më e madhe se 0.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(pa etiketë)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Sh&amp;uma:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Paguaj &amp;drejt:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiketë:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Ngjit nga memorja e sistemit</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Krijoni një etiketë për këtë adresë që t'ja shtoni librit të adresave</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Ngjit nga memorja e sistemit</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Hapur deri më %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/I pakonfirmuar</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 konfirmimet</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, nuk është transmetuar me sukses deri tani</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>i/e panjohur</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sasia</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Detajet e transaksionit</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Ky panel tregon një përshkrim të detajuar të transaksionit</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Lloji</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresë</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sasia</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Hapur deri më %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>I/E konfirmuar(%1 konfirmime)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>I krijuar por i papranuar</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Marrë me</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Dërguar drejt</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pagesë ndaj vetvetes</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(p/a)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Received with</source>
        <translation>Marrë me</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Dërguar drejt</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minuar</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopjo adresën</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Lloji</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiketë</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresë</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sasia</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Insufficient funds</source>
        <translation>Fonde te pamjaftueshme</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Rikerkim</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Problem</translation>
    </message>
</context>
</TS>